// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-

const St = imports.gi.St;
const Main = imports.ui.main;
const Tweener = imports.ui.tweener;
const Lang = imports.lang;
const Mainloop = imports.mainloop;
const Atk = imports.gi.Atk;

const CHECK_CLIPBOARD_TIMEOUT = 500; // milliseconds
const HIDE_NOTIFICATION_TIMEOUT = 1500; // milliseconds

let current_text;
let word_count;
let label;
let notification;
let clipboard;
let checkClipboardContentId;

const MAX_WORDS = 20;

function _getTextCallback(clipboard, new_text) {
    if (current_text != new_text) {
        let words;

        current_text = new_text;

        if (current_text != null) {
            words = current_text.split(" ");
            word_count = words.length;
        } else {
            word_count = 0;
        }
        _showNotification();
    }
}

function _checkClipboardContent() {
    clipboard.get_text(Lang.bind(this, _getTextCallback));

    return true;
}

function _hideNotification() {
    notification.visible = false;

    return false;
}

function _showNotification() {
    if (!notification) {
        notification = new St.Button({ accessible_role: Atk.Role.NOTIFICATION });

        notification.opacity = 0;
        label = new St.Label();
        label.visible = true;

        notification.set_child(label);
        Main.uiGroup.add_actor(notification);
    }

    notification.visible = true;
    let monitor = Main.layoutManager.primaryMonitor;

    notification.set_position(Math.floor(monitor.width / 2 - notification.width / 2),
                              Math.floor(monitor.height / 2 - notification.height / 2));

    if (word_count < MAX_WORDS)
        label.text = _("Clipboard: ") + current_text;
    else
        label.text = _("Clipboard: ") + word_count + _(" words copied to the clipboard");

    // idle doesn't work here
    Mainloop.timeout_add (HIDE_NOTIFICATION_TIMEOUT, Lang.bind(this, _hideNotification));
}

function init() {
}

function enable() {
    clipboard = St.Clipboard.get_default();
    current_text = "";
    checkClipboardContentId =
        Mainloop.timeout_add (CHECK_CLIPBOARD_TIMEOUT, Lang.bind(this, _checkClipboardContent));
}

function disable() {
    if (checkClipboardContentId != 0)
        Mainloop.source_remove(checkClipboardContentId);
}
